# krex

A lightweight Python package providing minimal trading functions for selected exchanges, organized by exchange-specific modules.

## Contributing

Check out the [Contributing Guide](.github/CONTRIBUTING.md).
